use std::{collections::HashMap, env::consts::DLL_EXTENSION, path::Path};

use serde::Deserialize;

pub(super) type Revision = git2::Oid;

#[derive(Debug, Deserialize)]
pub struct InstallInfo {
    pub url: String,

    pub files: Vec<String>,
}

pub type LanguageDefs = HashMap<String, InstallInfo>;

pub struct LanguageDb(Vec<LanguageDefs>);

impl LanguageDb {
    pub fn new(sources: Vec<HashMap<String, InstallInfo>>) -> Self {
        Self(sources)
    }

    pub fn get(&self, language: &str) -> Option<&InstallInfo> {
        for source in &self.0 {
            if let Some(info) = source.get(language) {
                return Some(info);
            }
        }
        None
    }

    pub fn into_keys(self) -> impl Iterator<Item = String> {
        self.0.into_iter().flat_map(HashMap::into_keys)
    }
}

pub fn is_installed(language: &str, parser_dir: &Path) -> bool {
    parser_dir
        .join(language)
        .with_extension(DLL_EXTENSION)
        .exists()
}
